Documentation
¶
Overview ¶
QuarkDash Module
@git https://github.com/devsdaddy/quarkdash-go @version 1.2.1 @author Elijah Rastorguev @build 1023 @website https://dev.to/devsdaddy @updated 28.08.2026
QuarkDash Implementation ¶
@git https://github.com/devsdaddy/quarkdash-go @version 1.2.1 @author Elijah Rastorguev @build 1023 @website https://dev.to/devsdaddy @updated 28.08.2026
Index ¶
- Constants
- Variables
- func Argon2idSync(pass string, salt []byte, mc, tc, dkLen int) []byte
- func Argon2idSyncBytes(pass, salt []byte, mc, tc, dkLen int) []byte
- func BytesToHex(b []byte) string
- func BytesToText(b []byte) string
- func ConcatBytes(arrays ...[]byte) []byte
- func DeriveKeyForQuarkDash(pass string, salt []byte, opts PassphraseOptions) (sess, mac []byte)
- func DerivePassphrase(pass string, opts PassphraseOptions) (key, salt []byte)
- func GenerateSalt(length int) []byte
- func PBKDF2Sync(pass string, salt []byte, iter, dkLen int) []byte
- func PBKDF2SyncBytes(pass, salt []byte, iter, dkLen int) []byte
- func RandomBytes(n int) []byte
- func SHA256Hash(data []byte) []byte
- func SHA512Hash(data []byte) []byte
- func SecureZeroBytes(b []byte)
- func Shake256Hash(data []byte, outLen int) []byte
- func TextToBytes(s string) []byte
- func WithCipher(ct CipherType) func(*Options)
- func WithKDF(k KDF) func(*Options)
- func WithKeyExchange(kx KeyExchange) func(*Options)
- func WithMAC(m MAC) func(*Options)
- func WithMaxPacketWindow(n int) func(*Options)
- func WithRekeyPolicy(p RekeyPolicy) func(*Options)
- func WithTimestampToleranceMs(n int64) func(*Options)
- func WithUsePerMessageNonce(v bool) func(*Options)
- type BaseRingLWE
- type ChaChaKeystream
- type Cipher
- type CipherType
- type Encryptor
- type GimliKeystream
- type GrpcCall
- type KDF
- type KeyExchange
- type MAC
- type NTTProtectionOptions
- type Options
- type PassphraseOptions
- type QDGRPC
- type QDHTTP
- type QDHTTPOptions
- type QDWebSocket
- type QuarkDash
- func (qd *QuarkDash) ApplyRekey(token []byte) error
- func (qd *QuarkDash) Decrypt(ciphertext []byte) ([]byte, error)
- func (qd *QuarkDash) Dispose()
- func (qd *QuarkDash) Encrypt(plaintext []byte) ([]byte, error)
- func (qd *QuarkDash) FinalizeSession(ciphertext []byte) error
- func (qd *QuarkDash) GenerateKeyPair() []byte
- func (qd *QuarkDash) GetMacKey() []byte
- func (qd *QuarkDash) GetRekeyCounter() int
- func (qd *QuarkDash) GetRekeyStats() (counter, bytesEnc, messagesEnc int, lastRekey time.Time, policy RekeyPolicy)
- func (qd *QuarkDash) GetSessionKey() []byte
- func (qd *QuarkDash) InitializeSession(peerPublicKey []byte, isInitiator bool) ([]byte, error)
- func (qd *QuarkDash) NeedsRekey() bool
- func (qd *QuarkDash) Rekey() ([]byte, error)
- func (qd *QuarkDash) SetRekeyPolicy(p RekeyPolicy)
- type QuarkDashChaCha
- type QuarkDashGimli
- type QuarkDashKDF
- type QuarkDashMAC
- type QuarkDashRLWE
- type QuarkDashRRLWE
- type RRLWE
- type RekeyOptions
- type RekeyPolicy
- type RingLWE
- type WSLike
Constants ¶
const ( CipherChaCha20 = cipher.CipherChaCha20 CipherGimli = cipher.CipherGimli )
Variables ¶
var ( ErrSessionNotEstablished = errors.New("session not established") ErrSessionNotInitialized = errors.New("session not initialized") ErrMACVerificationFailed = errors.New("MAC verification failed") ErrTimestampOutOfWindow = errors.New("timestamp out of window") ErrReplayDetected = errors.New("replay detected") ErrRekeyCounterMismatch = errors.New("rekey counter mismatch") ErrInvalidNonce = errors.New("nonce must be 12 bytes") ErrInvalidCiphertext = errors.New("invalid ciphertext") )
var DefaultNTTProtection = ringlwe.DefaultNTTProtection
var DefaultRekeyPolicy = rekey.DefaultRekeyPolicy
Functions ¶
func Argon2idSyncBytes ¶
func BytesToHex ¶
func BytesToText ¶
func ConcatBytes ¶
func DeriveKeyForQuarkDash ¶
func DeriveKeyForQuarkDash(pass string, salt []byte, opts PassphraseOptions) (sess, mac []byte)
func DerivePassphrase ¶
func DerivePassphrase(pass string, opts PassphraseOptions) (key, salt []byte)
func GenerateSalt ¶
func PBKDF2SyncBytes ¶
func RandomBytes ¶
func SHA256Hash ¶
func SHA512Hash ¶
func SecureZeroBytes ¶
func SecureZeroBytes(b []byte)
func Shake256Hash ¶
============================================================================= Hashes =============================================================================
func TextToBytes ¶
============================================================================= Re-export core utils =============================================================================
func WithCipher ¶
func WithCipher(ct CipherType) func(*Options)
func WithKeyExchange ¶
func WithKeyExchange(kx KeyExchange) func(*Options)
func WithMaxPacketWindow ¶
func WithRekeyPolicy ¶
func WithRekeyPolicy(p RekeyPolicy) func(*Options)
func WithUsePerMessageNonce ¶
Types ¶
type BaseRingLWE ¶
type BaseRingLWE = ringlwe.BaseRingLWE
============================================================================= Ring LWE =============================================================================
type ChaChaKeystream ¶
type ChaChaKeystream = cipher.ChaChaKeystream
type GimliKeystream ¶
type GimliKeystream = cipher.GimliKeystream
type KeyExchange ¶
type KeyExchange interface {
GenerateKeyPair() (pub, priv []byte)
Encapsulate(pubKey []byte) (ciphertext, sharedSecret []byte, err error)
Decapsulate(privKey, peerPubKey, ciphertext []byte) ([]byte, error)
}
KeyExchange - key exchange interface (KEM).
type NTTProtectionOptions ¶
type NTTProtectionOptions = ringlwe.NTTProtectionOptions
NTTProtectionOptions - NTT security options
type Options ¶
type Options struct {
Cipher CipherType
KDF KDF
MAC MAC
KeyExchange KeyExchange
MaxPacketWindow int
TimestampToleranceMs int64
Rekey RekeyOptions
UsePerMessageNonce bool
}
Options - basic QuarkDash configuration.
type PassphraseOptions ¶
type PassphraseOptions = passphrase.PassphraseOptions
============================================================================= Passphrase =============================================================================
type QDHTTP ¶
============================================================================= Transport wrappers - Lightweight transport =============================================================================
func NewQDHTTP ¶
func NewQDHTTP(enc Encryptor, opts ...QDHTTPOptions) *QDHTTP
type QDHTTPOptions ¶
type QDHTTPOptions = transport.QDHTTPOptions
type QDWebSocket ¶
type QDWebSocket = transport.QDWebSocket
func NewQDWebSocket ¶
func NewQDWebSocket(enc Encryptor, ws WSLike) *QDWebSocket
func WrapWebSocket ¶
func WrapWebSocket(enc Encryptor, ws WSLike) *QDWebSocket
type QuarkDash ¶
type QuarkDash struct {
// contains filtered or unexported fields
}
QuarkDash - general protocol class. Threadsafety (sync.Mutex), support per-message nonce, replay-security and rekey (key rotation).
func (*QuarkDash) ApplyRekey ¶
ApplyRekey apply key rotation token from peer (decrypt using old session, when derive).
func (*QuarkDash) FinalizeSession ¶
FinalizeSession complete handshake on receiver side.
func (*QuarkDash) GenerateKeyPair ¶
GenerateKeyPair generates key pair (pub 1024B, private 512B).
func (*QuarkDash) GetRekeyCounter ¶
GetRekeyCounter return key rotation counter.
func (*QuarkDash) GetRekeyStats ¶
func (qd *QuarkDash) GetRekeyStats() (counter, bytesEnc, messagesEnc int, lastRekey time.Time, policy RekeyPolicy)
GetRekeyStats return key rotation static.
func (*QuarkDash) GetSessionKey ¶
GetSessionKey / GetMacKey - for tests/debugging.
func (*QuarkDash) InitializeSession ¶
InitializeSession start a handshake. If isInitiator=true, return ciphertext to send to peer.
func (*QuarkDash) NeedsRekey ¶
NeedsRekey checks, need key rotation or not using current policy.
func (*QuarkDash) Rekey ¶
Rekey generates a key rotation token (encrypt payload with old session, and derive new keys).
func (*QuarkDash) SetRekeyPolicy ¶
func (qd *QuarkDash) SetRekeyPolicy(p RekeyPolicy)
SetRekeyPolicy update rotation policy.
type QuarkDashChaCha ¶
type QuarkDashChaCha = cipher.QuarkDashChaCha
============================================================================= Ciphers (cipher) - re-export =============================================================================
func NewQuarkDashChaCha ¶
func NewQuarkDashChaCha(key, nonce []byte) (*QuarkDashChaCha, error)
type QuarkDashGimli ¶
type QuarkDashGimli = cipher.QuarkDashGimli
func NewQuarkDashGimli ¶
func NewQuarkDashGimli(key, nonce []byte) (*QuarkDashGimli, error)
type QuarkDashKDF ¶
type QuarkDashKDF = core.QuarkDashKDF
============================================================================= KDF / MAC =============================================================================
func NewQuarkDashKDF ¶
func NewQuarkDashKDF() *QuarkDashKDF
type QuarkDashMAC ¶
type QuarkDashMAC = core.QuarkDashMAC
func NewQuarkDashMAC ¶
func NewQuarkDashMAC() *QuarkDashMAC
type QuarkDashRLWE ¶
type QuarkDashRLWE = RingLWE
type QuarkDashRRLWE ¶
type QuarkDashRRLWE = RRLWE
type RRLWE ¶
func NewQuarkDashRRLWE ¶
func NewQuarkDashRRLWE() *RRLWE
type RekeyOptions ¶
type RekeyOptions struct {
Policy RekeyPolicy
AutoRekey bool
OnRekey func(counter int)
}
RekeyOptions - key rotation options.
type RingLWE ¶
func NewQuarkDashRLWE ¶
func NewQuarkDashRLWE() *RingLWE
func NewRingLWE ¶
func NewRingLWE() *RingLWE
Directories
¶
| Path | Synopsis |
|---|---|
|
QuarkDash ChaCha20 Implementation
|
QuarkDash ChaCha20 Implementation |
|
QuarkDash KDF Implementation
|
QuarkDash KDF Implementation |
|
QuarkDash SHA Implementation
|
QuarkDash SHA Implementation |
|
QuarkDash Passphrase Implementation
|
QuarkDash Passphrase Implementation |
|
QuarkDash Key Rotation Implementation
|
QuarkDash Key Rotation Implementation |
|
QuarkDash Key Ring-LWE Implementation
|
QuarkDash Key Ring-LWE Implementation |
|
QuarkDash gRPC Wrapper
|
QuarkDash gRPC Wrapper |